@@ -61,7 +61,7 @@ get_auth_key_from_cell(ed25519_public_key_t *auth_key_out,
   default:
     /* Getting here is really bad as it means we got a unknown cell type from
      * this file where every call has an hardcoded value. */
-    tor_assert(0); /* LCOV_EXCL_LINE */
+    tor_assert_unreached(); /* LCOV_EXCL_LINE */
   }
   tor_assert(key_array);
   tor_assert(auth_key_len == sizeof(auth_key_out->pubkey));
